@@ -1,20 +1,18 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
 /*
-** $Id: cgi.c,v 1.32 2006/05/03 01:57:06 mrsam Exp $
+** $Id: cgi.c,v 1.36 2007/05/01 03:01:57 mrsam Exp $
 */
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<string.h>
+#include	<ctype.h>
+#include	<errno.h>
 #include	"cgi.h"
 
-#if	HAVE_CONFIG_H
-#include	"config.h"
-#endif
-
 #if	HAVE_UNISTD_H
 #include	<unistd.h>
 #endif
@@ -349,12 +347,7 @@ int	c;
 
 	while (*q)
 	{
-		/*
-		** 0xA0 - Win32 versions of navigator convert TEXTAREA fillins
-		** of &nbsp; to 0xA0.
-		*/
-
-		if (*q == '+' || *q == (char)0xA0)
+		if (*q == '+')
 		{
 			*p++=' ';
 			q++;
@@ -473,17 +466,16 @@ off_t	dummy;
 
 		*formargptr=0;
 		{
-		char	*name=strdup(disposition_name);
-		char	*value=strdup(formargbuf);
-		char	*p, *q;
+			char	*name=strdup(disposition_name);
+			char	*value=strdup(formargbuf);
+			char	*p, *q;
 
-			/* Just like for GET/POSTs, strip CRs and convert
-			** 0xA0 to 0x20. */
+			/* Just like for GET/POSTs, strip CRs. */
 
 			for (p=q=value; *p; p++)
 			{
 				if (*p == '\r')	continue;
-				*q++ = (char)*p == (char)0xA0 ? ' ':*p;
+				*q++ = *p;
 			}
 			*q++='\0';
 			cgi_put(name, value);
@@ -659,3 +651,189 @@ struct cgigetfileinfo gfi={start_file, file, end_file, filenum, voidarg};
 }
 
 #endif
+
+/* cookies */
+
+int cgi_set_cookie_url(struct cgi_set_cookie_info *cookie_info,
+		       const char *url)
+{
+	const char *p;
+
+	if (cookie_info->domain)
+		free(cookie_info->domain);
+	if (cookie_info->path)
+		free(cookie_info->domain);
+
+	cookie_info->secure=0;
+
+	if (strncmp(url, "https://", 8) == 0)
+		cookie_info->secure=1;
+
+	for (p=url; *p; p++)
+	{
+		if (*p == ':')
+		{
+			url= ++p;
+			break;
+		}
+
+		if (*p == '/')
+			break;
+	}
+
+	if (strncmp(url, "//", 2) == 0)
+	{
+		p= url += 2;
+
+		while (*url)
+		{
+			if (*url == '/')
+				break;
+			++url;
+		}
+
+		if ((cookie_info->domain=malloc(url-p+1)) == NULL)
+			return -1;
+
+		memcpy(cookie_info->domain, p, url-p);
+		cookie_info->domain[url-p]=0;
+	}
+
+	if ((cookie_info->path=strdup(url)) == NULL)
+		return -1;
+	return 0;
+}
+
+void cgi_set_cookies(struct cgi_set_cookie_info *cookies,
+		     size_t n_cookies)
+{
+	size_t i;
+	const char *sep="";
+
+	printf("Set-Cookie: ");
+
+	for (i=0; i<n_cookies; i++, cookies++)
+	{
+		printf("%s%s=\"%s\"; ", sep, cookies->name, cookies->value);
+		sep="; ";
+
+		if (cookies->path)
+			printf("Path=\"%s\"; ", cookies->path);
+
+		if (cookies->secure)
+			printf("Secure; ");
+
+		if (cookies->age >= 0)
+			printf("Max-Age=%d; ", cookies->age);
+		printf("Version=1");
+	}
+
+	printf("\n");
+	fflush(stdout);
+}
+
+/*
+** Parse Cookie: header
+**
+** get_cookie_value() skips over a single cookie name=value, returning # of
+** bytes, excluding quotes (if any), plus one more (for the trailing \0).
+**
+** out_ptr, if not NULL, receives ptr to the next byte after name=value
+**
+** out_value, if not NULL receives the cookie's value, excluding any quotes.
+*/
+
+static size_t get_cookie_value(const char *ptr, const char **out_ptr,
+			       char *out_value)
+{
+	int in_quote=0;
+	size_t cnt=1;
+
+	while (*ptr)
+	{
+		if (!in_quote)
+		{
+			if (*ptr == ';' || *ptr == ',' ||
+			    isspace((int)(unsigned char)*ptr))
+				break;
+		}
+
+		if (*ptr == '"')
+		{
+			in_quote= ~in_quote;
+			++ptr;
+			continue;
+		}
+
+		if (out_value)
+			*out_value++ = *ptr;
+		++cnt;
+		++ptr;
+	}
+
+	if (out_value)
+		*out_value=0;
+
+	if (out_ptr)
+		*out_ptr=ptr;
+	return cnt;
+}
+
+/*
+** Search for a cookie.
+**
+** Returns NULL and sets errno=ENOENT, if cookie not found.
+**
+** Returns malloc-ed buffer that holds the cookie's value (or NULL if
+** malloc fails).
+*/
+
+char *cgi_get_cookie(const char *cookie_name)
+{
+	size_t cookie_name_len=strlen(cookie_name);
+	const char *cookie=getenv("HTTP_COOKIE");
+
+	if (!cookie)
+		cookie="";
+
+	while (*cookie)
+	{
+		if (isspace((int)(unsigned char)*cookie) ||
+		    *cookie == ';' || *cookie == ',')
+		{
+			++cookie;
+			continue;
+		}
+
+		if (strncmp(cookie, cookie_name, cookie_name_len) == 0 &&
+		    cookie[cookie_name_len] == '=')
+		{
+			char *buf;
+
+			cookie += cookie_name_len;
+			++cookie;
+
+			if ((buf=malloc(get_cookie_value(cookie, NULL, NULL)))
+			    == NULL)
+			{
+				return NULL;
+			}
+
+			get_cookie_value(cookie, NULL, buf);
+
+			if (*buf == 0) /* Pretend not found */
+			{
+				free(buf);
+				errno=ENOENT;
+				return NULL;
+			}
+
+			return buf;
+		}
+
+		get_cookie_value(cookie, &cookie, NULL);
+	}
+
+	errno=ENOENT;
+	return NULL;
+}
