@@ -1,15 +1,11 @@
 /*
-** Copyright 1998 - 2004 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
 /*
-** $Id: cgiredirect.c,v 1.5 2004/04/11 23:15:55 mrsam Exp $
+** $Id: cgiredirect.c,v 1.6 2007/02/24 19:02:59 mrsam Exp $
 */
-#if	HAVE_CONFIG_H
-#include	"config.h"
-#endif
-
 #include	"cgi.h"
 #include	<stdio.h>
 
