@@ -7,14 +7,14 @@
 #define	cdfilters_h
 
 /*
-**	$Id: cdfilters.h,v 1.3 2000/01/18 03:28:38 mrsam Exp $
+**	$Id: cdfilters.h,v 1.4 2007/06/30 03:24:11 mrsam Exp $
 */
 
 #if	HAVE_CONFIG_H
 #include	"config.h"
 #endif
 
-#include	"afx/afx.h"
+#include	<string>
 
 int run_filter(
 	const char *,		// Filename  containing the message
@@ -23,7 +23,7 @@ int run_filter(
 				// recipients
 	int,			// whitelisted flag, used to select
 				// filters
-	CString (*)(unsigned, void *),	// Function to return message id
+	std::string (*)(unsigned, void *), // Function to return message id
 				//  #n (n is 0..count-1)
 	void *);		// Second argument to function.
 
