@@ -27,7 +27,7 @@
 #include	<sys/wait.h>
 #endif
 
-static const char rcsid[]="$Id: courierfilter.c,v 1.10 2006/05/28 15:29:51 mrsam Exp $";
+static const char rcsid[]="$Id: courierfilter.c,v 1.11 2007/05/05 03:04:41 mrsam Exp $";
 
 #define	LOCKFILE	FILTERSOCKETDIR "/.lock"
 
@@ -290,7 +290,7 @@ static int start()
 	int	pipe3fd[2];
 	char	temp_buf;
 
-	lockfd=ll_daemon_start(PIDFILE);
+	lockfd=ll_daemon_start(LOCKFILE);
 	if (lockfd <= 0)
 	{
 		close(3);
