@@ -15,7 +15,7 @@
 extern "C" {
 #endif
 
-static const char comtrack_h_rcsid[]="$Id: comtrack.h,v 1.2 2005/01/30 05:21:28 mrsam Exp $";
+static const char comtrack_h_rcsid[]="$Id: comtrack.h,v 1.3 2007/07/21 20:43:12 mrsam Exp $";
 
 #define TRACK_NHOURS 2
 
@@ -29,6 +29,10 @@ int track_find(const char *address, time_t *timestamp);
 
 void track_save(const char *address, int status);
 
+int track_read(int (*cb_func)(time_t timestamp, int status,
+			      const char *address, void *voidarg),
+	       void *voidarg);
+
 #ifdef	__cplusplus
 } ;
 #endif
