@@ -51,7 +51,7 @@
 #endif
 #endif
 
-static const char rcsid[]="$Id: faxconvert.c,v 1.4 2003/06/02 23:49:35 mrsam Exp $";
+static const char rcsid[]="$Id: faxconvert.c,v 1.5 2006/01/23 23:22:10 mrsam Exp $";
 
 #include "filterbindir.h"
 #include "faxtmpdir.h"
@@ -470,7 +470,7 @@ static int do_filter(struct rfc2045 *m,		/* The MIME section */
 		     struct faxconvert_info *info,	/* Housekeeping */
 		     int is_cover_page)	/* We're generated text/plain cover */
 {
-	pid_t pidnum;
+	pid_t pidnum=0;
 	int filter_fd;
 	off_t start_pos, start_body, end_pos, dummy2;
 	int n, rc;
