@@ -2,9 +2,9 @@
 #
 # TITLE: MySQL
 #
-# $Id: admin-15mysql.pl,v 1.4 2001/07/08 02:07:41 mrsam Exp $
+# $Id: admin-15mysql.pl,v 1.7 2004/10/24 02:01:55 mrsam Exp $
 #
-# Copyright 2001 Double Precision, Inc.  See COPYING for
+# Copyright 2001-2004 Double Precision, Inc.  See COPYING for
 # distribution information.
 
 use webadmin;
@@ -12,8 +12,7 @@ use webadmin;
 my $errstr="";
 
 display_form("notsupp.html")
-    unless -f "$libexecdir/authlib/authmysql" ||
-    -f "$libexecdir/authlib/authdaemond.mysql";
+    unless -f "$authmysqlrc";
 
 if ($cgi->param("Save"))
 {
@@ -43,6 +42,7 @@ if ($cgi->param("Save"))
 	      "MYSQL_DEFAULT_DOMAIN=DEFAULT_DOMAIN=DEFAULT_DOMAIN",
 	      "MYSQL_NAME_FIELD=MYSQL_NAME_FIELD=NAME_FIELD",
 	      "MYSQL_MAILDIR_FIELD=MYSQL_MAILDIR_FIELD=MAILDIR_FIELD",
+	      "MYSQL_DEFAULTDELIVERY=MYSQL_DEFAULTDELIVERY=DEFAULTDELIVERY",
 	      "MYSQL_QUOTA_FIELD=MYSQL_QUOTA_FIELD=QUOTA_FIELD",
 	      "MYSQL_WHERE_CLAUSE=MYSQL_WHERE_CLAUSE=WHERE_CLAUSE"
 	      ))
@@ -59,7 +59,7 @@ if ($cgi->param("Save"))
     {
 	$errstr="\@SAVED\@";
     }
-    changed("test ! -x $libexecdir/authlib/authdaemond || $libexecdir/authlib/authdaemond restart");
+    changed("$authdaemond restart");
 }
 
 my $mysql=ReadKWConfigFile("authmysqlrc");
@@ -81,6 +81,7 @@ display_form("admin-15mysql.html",
 		 "LOGIN_FIELD" => $$mysql{'MYSQL_LOGIN_FIELD'},
 		 "HOME_FIELD" => $$mysql{'MYSQL_HOME_FIELD'},
 		 "MAILDIR_FIELD" => $$mysql{'MYSQL_MAILDIR_FIELD'},
+		 "DEFAULTDELIVERY" => $$mysql{'MYSQL_DEFAULTDELIVERY'},
 		 "QUOTA_FIELD" => $$mysql{'MYSQL_QUOTA_FIELD'},
 		 "NAME_FIELD" => $$mysql{'MYSQL_NAME_FIELD'},
 		 "CLEAR_PWFIELD" => $$mysql{'MYSQL_CLEAR_PWFIELD'},
