@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2003 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -59,7 +59,7 @@
 #include	"imapwrite.h"
 #include	"imapd.h"
 
-static const char rcsid[]="$Id: imapscanclient.c,v 1.45 2004/07/19 23:54:14 mrsam Exp $";
+static const char rcsid[]="$Id: imapscanclient.c,v 1.46 2007/10/13 13:41:56 mrsam Exp $";
 
 static int do_imapscan_maildir2(struct imapscaninfo *, const char *,
 				int, int, struct uidplus_info *);
@@ -787,6 +787,8 @@ int	dowritecache=0;
 	/* bk: ignore if failed to open file */
 	if (!ro && dowritecache && fp)
 	{
+		int need_fclose;
+
 	/* Step 7 - write out the new cache file */
 
 		version=IMAPDBVERSION;
@@ -800,10 +802,13 @@ int	dowritecache=0;
 				tempinfo_array[i]->filename);
 			if (q)	*q=MDIRSEP[0];
 		}
-		if (fflush(fp) || ferror(fp) || fclose(fp))
+
+		need_fclose=1;
+		if (fflush(fp) || ferror(fp) || ((need_fclose=0), fclose(fp)))
 		{
 			imapscanfail(dir);
-			fclose(fp);
+			if (need_fclose)
+				fclose(fp);
 			/* bk: ignore if failed */
 			unlink(newdbfilepath);
 			unlink(dbfilepath);
