@@ -6,7 +6,7 @@
 #ifndef	rfc1035_h
 #define	rfc1035_h
 
-static const char rfc1035_h_rcsid[]="$Id: rfc1035.h,v 1.6 2004/08/15 16:41:02 mrsam Exp $";
+static const char rfc1035_h_rcsid[]="$Id: rfc1035.h,v 1.7 2005/06/24 17:47:33 mrsam Exp $";
 
 
 #if	HAVE_CONFIG_H
@@ -186,8 +186,10 @@ int rfc1035_resolve_cname(
 					** the name to query */
 		unsigned,		/* Query type */
 		unsigned,		/* Query class */
-		struct rfc1035_reply **);
-					/* Ptr set to reply received */
+		struct rfc1035_reply **, /* Ptr set to reply received */
+		int); /* Extended flags: */
+
+#define RFC1035_X_RANDOMIZE 1    /* Randomize query results */
 
 	/*
 	** Always call replyfree when done.
@@ -485,6 +487,10 @@ struct rfc1035_reply {
 	} ;
 
 struct rfc1035_reply *rfc1035_replyparse(const char *, unsigned);
+void rfc1035_rr_rand_an(struct rfc1035_reply *rr);
+void rfc1035_rr_rand_ns(struct rfc1035_reply *rr);
+void rfc1035_rr_rand_ar(struct rfc1035_reply *rr);
+void rfc1035_rr_rand(struct rfc1035_reply *rr);
 
 void rfc1035_dump(struct rfc1035_reply *, FILE *);
 
