@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: attachments.c,v 1.46 2006/05/03 01:57:06 mrsam Exp $
+** $Id: attachments.c,v 1.47 2006/05/28 15:29:52 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -994,10 +994,8 @@ int attach_upload(const char *draft,
 
 	if (pid1 == 0)
 	{
-		close(0);
-		dup(attachfd);
-		close(1);
-		dup(pipefd[1]);
+		dup2(attachfd, 0);
+		dup2(pipefd[1], 1);
 		close(attachfd);
 		close(newdraftfd);
 		close(pipefd[0]);
