@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: newmsg.c,v 1.65 2007/05/06 21:49:29 mrsam Exp $
+** $Id: newmsg.c,v 1.66 2007/08/30 01:38:49 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -73,12 +73,13 @@ static void newmsg_header(const char *label, const char *field,
 int		hdrmaxlen=512;
 const char	*p=getarg("HDRMAXLEN");
 
-	if (p && (atoi(p) > hdrmaxlen))
-		hdrmaxlen=atoi(p);
-
 #if	HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 #endif
+
+	if (p && (atoi(p) > hdrmaxlen))
+		hdrmaxlen=atoi(p);
+
 	printf("<tr><th align=\"right\"><p class=\"new-message-header\">"
 	       "<span class=\"new-message-header-%s\">%s</span></p></th>"
 	       "<td width=\"6\">&nbsp;</td>",
@@ -413,6 +414,7 @@ void newmsg_init(const char *folder, const char *pos)
 	FILE	*fp;
 	int	attachcnt=0;
 	char	*cursubj, *curto, *curcc, *curbcc, *curfrom, *curreplyto;
+	int wbnochangingfrom;
 
 	/* Picking up an existing draft? */
 
@@ -560,7 +562,7 @@ void newmsg_init(const char *folder, const char *pos)
 	printf("<table width=\"100%%\" border=\"0\" cellspacing=\"0\" cellpadding=\"4\" class=\"new-message-box\"><tr><td>\n");
 
 	printf("<table border=\"0\" width=\"100%%\">\n");
-	int wbnochangingfrom=auth_getoptionenvint("wbnochangingfrom");
+	wbnochangingfrom=auth_getoptionenvint("wbnochangingfrom");
 	if (wbnochangingfrom < 2)
 		newmsg_header_rfc822(fromlab, "headerfrom", curfrom,
 			*cgi("from") ? cgi("from"):
