@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2008 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: pref.c,v 1.30 2006/07/07 23:17:18 mrsam Exp $
+** $Id: pref.c,v 1.31 2008/02/03 15:25:06 mrsam Exp $
 */
 #include	"pref.h"
 #include	"config.h"
@@ -29,6 +29,7 @@
 #define	LDAP		"LDAP"
 #define FLOWEDTEXT	"NOFLOWEDTEXT"
 #define NOARCHIVE	"NOARCHIVE"
+#define NOAUTORENAMESENT	"NOAUTORENAMESENT"
 #define STARTOFWEEK	"STARTOFWEEK"
 #define WIKITEXT		"WIKITEXT"
 
@@ -37,6 +38,7 @@
 #define	HTML_PREF "doshowhtml"
 #define FLOWEDTEXT_PREF "noflowedtext"
 #define NOARCHIVE_PREF "noarchive"
+#define NOAUTORENAMESENT_PREF "noautorenamesent"
 
 #define DEFAULTKEY	"DEFAULTKEY"
 
@@ -47,6 +49,7 @@ int pref_flagpagesize;
 int pref_autopurge;
 int pref_noflowedtext;
 int pref_noarchive;
+int pref_noautorenamesent;
 int pref_startofweek;
 int pref_wikifmt;
 
@@ -59,6 +62,7 @@ extern void set_sqwebpass(const char *);
 #endif
 extern void output_attrencoded_oknl(const char *);
 extern const char *sqwebmail_mailboxid;
+extern void rename_sent_folder(int really);
 
 static const char hex[]="0123456789ABCDEF";
 
@@ -99,6 +103,18 @@ char	*q, *r;
 	pref_flagfullheaders=0;
 	pref_flagsortorder=0;
 	pref_flagpagesize=10;
+	pref_noarchive=0;
+
+	{
+		const char *autorenamesent=AUTORENAMESENT;
+
+		const char *p=getenv("SQWEBMAIL_AUTORENAMESENT");
+		if (p && *p)
+			autorenamesent = p;
+
+		pref_noautorenamesent=strncmp(autorenamesent, "no", 2) == 0;
+	}
+
 	pref_startofweek=0;
 	pref_autopurge=AUTOPURGE;
 	pref_showhtml=1;
@@ -146,6 +162,9 @@ char	*q, *r;
 			if (strncmp(r, NOARCHIVE, sizeof(NOARCHIVE)-1) == 0
 				&& r[sizeof(NOARCHIVE)-1] == '=')
 				pref_noarchive=atoi(r+sizeof(NOARCHIVE));
+			if (strncmp(r, NOAUTORENAMESENT, sizeof(NOAUTORENAMESENT)-1) == 0
+				&& r[sizeof(NOAUTORENAMESENT)-1] == '=')
+				pref_noautorenamesent=atoi(r+sizeof(NOAUTORENAMESENT));
 			if (strncmp(r, FROM, sizeof(FROM)-1) == 0
 				&& r[sizeof(FROM)-1] == '=')
 			{
@@ -253,10 +272,10 @@ char	*p;
 char	*q;
 
 	sprintf(buf, SORTORDER "=%c " PAGESIZE "=%d " AUTOPURGE_V "=%d "
-		FLOWEDTEXT "=%d " NOARCHIVE "=%d " STARTOFWEEK "=%d",
+		FLOWEDTEXT "=%d " NOARCHIVE "=%d " NOAUTORENAMESENT "=%d "
+		STARTOFWEEK "=%d",
 		pref_flagsortorder, pref_flagpagesize, pref_autopurge,
-		pref_noflowedtext,
-		pref_noarchive,
+		pref_noflowedtext, pref_noarchive, pref_noautorenamesent,
 		pref_startofweek);
 
 	if (pref_flagisoldest1st)
@@ -306,14 +325,15 @@ void pref_setprefs()
 	char	*p;
 	char	*q;
 
-		sprintf(buf, SORTORDER "=%c " PAGESIZE "=%s "
-			AUTOPURGE_V "=%s " FLOWEDTEXT "=%s "
-			NOARCHIVE "=%s " STARTOFWEEK "=%d",
-			*cgi("sortorder"), cgi("pagesize"),
-			cgi("autopurge"),
+		sprintf(buf, SORTORDER "=%c " PAGESIZE "=%s " AUTOPURGE_V "=%s "
+			FLOWEDTEXT "=%s "
+			NOARCHIVE "=%s "
+			NOAUTORENAMESENT "=%s "
+			STARTOFWEEK "=%d",
+			*cgi("sortorder"), cgi("pagesize"), cgi("autopurge"),
 			*cgi(FLOWEDTEXT_PREF) ? "1":"0",
 			*cgi(NOARCHIVE_PREF) ? "1":"0",
-
+			*cgi(NOAUTORENAMESENT_PREF) ? "1":"0",
 			(int)((unsigned)atoi(cgi(STARTOFWEEK)) % 7)
 			);
 
@@ -339,6 +359,8 @@ void pref_setprefs()
 		savemailinglists(cgi("mailinglists"));
 
 		printf("%s\n", getarg("PREFSOK"));
+
+		rename_sent_folder(0);
 	}
 
 	if (*cgi("do.changepwd"))
@@ -440,6 +462,12 @@ void pref_displaynoarchive()
 		NOARCHIVE_PREF, NOARCHIVE_PREF, pref_noarchive ? " checked=\"checked\"":"");
 }
 
+void pref_displaynoautorenamesent()
+{
+	printf("<input type=\"checkbox\" name=\"%s\" id=\"%s\"%s />",
+		NOAUTORENAMESENT_PREF, NOAUTORENAMESENT_PREF, pref_noautorenamesent ? " checked=\"checked\"":"");
+}
+
 void pref_displayautopurge()
 {
 	printf("<input type=\"text\" name=\"autopurge\" value=\"%d\" size=\"2\" maxlength=\"2\" />",
